/* $NetBSD: psym_rbrace.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the parser symbol psym_rbrace, which represents '}' and finishes
 * the previous '{'.
 *
 * See also:
 *	psym_lbrace.c
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
