/* $NetBSD: psym_semicolon.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the parser symbol psym_semicolon, which pushes a new statement on
 * the stack.
 *
 * This token is never stored on the stack itself.
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
